package de.hawhamburg.reachability.enumeration;

/**
 * Enumeration of defined reachability status states.<br><br>
 * 
 * This enumeration defines possible status states. These states are possible results of the reasoner within the 
 * reachability agent process.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public enum ReachabilityStatus {
    /**
     * The person is currently available.
     */
    AVAILABLE,
    /**
     * The person is busy, mind before interrupt.
     */
    BUSY,
    /**
     * The person shall not be interrupted, but it may be possible in case of emergency.
     */
    DO_NOT_DISTURB,
    /**
     * The person is unavailable. No communication attempts should be made. This may mean the inhabitant is not inside 
     * the building or has explicitly set his reachability status to this status.
     */
    UNAVAILABLE,
    /**
     * The status wasn't calculated up to know, but will probably be calculated soon.
     */
    NOT_CALCULATED;
}
